@@ -77,7 +77,7 @@ class ArchivePolicy(object):
         if aggregation_methods is None:
             self.aggregation_methods = self.DEFAULT_AGGREGATION_METHODS
         else:
-            self.aggregation_methods = set(aggregation_methods)
+            self.aggregation_methods = aggregation_methods
 
     @property
     def aggregation_methods(self):
@@ -141,8 +141,7 @@ OPTS = [
         'default_aggregation_methods',
         item_type=types.String(
             choices=ArchivePolicy.VALID_AGGREGATION_METHODS),
-        default=['mean', 'min', 'max', 'sum',
-                 'std', 'median', 'count', '95pct'],
+        default=['mean', 'min', 'max', 'sum', 'std', 'count'],
         help='Default aggregation methods to use in created archive policies'),
 ]
 
@@ -176,8 +175,6 @@ class ArchivePolicyItem(dict):
                 self['timespan'] = None
             else:
                 points = int(timespan / granularity)
-                if points <= 0:
-                    raise ValueError("Calculated number of points is < 0")
                 self['timespan'] = granularity * points
         else:
             points = int(points)
@@ -212,6 +209,14 @@ class ArchivePolicyItem(dict):
 
 
 DEFAULT_ARCHIVE_POLICIES = {
+    'bool': ArchivePolicy(
+        "bool", 3600, [
+            # 1 second resolution for 365 days
+            ArchivePolicyItem(granularity=1,
+                              timespan=365 * 24 * 60 * 60),
+        ],
+        aggregation_methods=("last",),
+    ),
     'low': ArchivePolicy(
         "low", 0, [
             # 5 minutes resolution for 30 days
